# SvgDataGrabber

A Python package for extracting data from SVG files.

- GitHub: [https://github.com/haiiliin/svgdatagrabber/](https://github.com/haiiliin/svgdatagrabber/)
- Documentation: [https://svgdatagrabber.readthedocs.io/en/latest/](https://svgdatagrabber.readthedocs.io/en/latest/)
- PyPI: [https://pypi.org/project/svgdatagrabber/](https://pypi.org/project/svgdatagrabber/)
- Read the Docs: [https://readthedocs.org/projects/svgdatagrabber/](https://readthedocs.org/projects/svgdatagrabber/)
